
pypocketfft version
-------------------

SciPy currently vendors [pypocketfft] at:

    commit 2147aaf37c6274cc77160f6b355ed9d120cfdc57
    Merge: 80bb41a 99599e1
    Author: Martin Reinecke <martin@mpa-garching.mpg.de>
    Date:   Sat Jan 11 17:09:17 2020 +0100

        Merge branch 'more_clang_fixes' into 'master'

        address more problems with clang (and follow its optimization hints)

        See merge request mtr/pypocketfft!35

pypocketfft: https://gitlab.mpcdf.mpg.de/mtr/pypocketfft
